@@ -3,7 +3,7 @@
 ##############################################################################
 ##
 ##  Canon Inkjet Printer Driver for Linux
-##  Copyright CANON INC. 2001-2023
+##  Copyright CANON INC. 2001-2024
 ##
 ##  This program is free software; you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
@@ -20,10 +20,10 @@
 ##
 ##############################################################################
 
-C_version="6.70-1"
-C_copyright_end="2023"
+C_version="6.80-1"
+C_copyright_end="2024"
 C_default_system="rpm"
-P_support_printer=("TS8700" "XK120" "GX5500" "GX1000" "GX2000" "TS6630" "TS7700" "TS7600i" "TS6730" "TR7800" "TS7700i" "TS7700A" "GX6500")
+P_support_printer=("G4090" "G4080" "G3090" "G3080" "TS8800" "XK130")
 
 L_INST_COM_01_01="Command executed = %s\n"
 
